//go:build go1.18
// +build go1.18

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.
// Code generated by Microsoft (R) AutoRest Code Generator.
// Changes may cause incorrect behavior and will be lost if the code is regenerated.

package armdashboard

import "time"

// ErrorAdditionalInfo - The resource management error additional info.
type ErrorAdditionalInfo struct {
	// READ-ONLY; The additional info.
	Info interface{} `json:"info,omitempty" azure:"ro"`

	// READ-ONLY; The additional info type.
	Type *string `json:"type,omitempty" azure:"ro"`
}

// ErrorDetail - The error detail.
type ErrorDetail struct {
	// READ-ONLY; The error additional info.
	AdditionalInfo []*ErrorAdditionalInfo `json:"additionalInfo,omitempty" azure:"ro"`

	// READ-ONLY; The error code.
	Code *string `json:"code,omitempty" azure:"ro"`

	// READ-ONLY; The error details.
	Details []*ErrorDetail `json:"details,omitempty" azure:"ro"`

	// READ-ONLY; The error message.
	Message *string `json:"message,omitempty" azure:"ro"`

	// READ-ONLY; The error target.
	Target *string `json:"target,omitempty" azure:"ro"`
}

// ErrorResponse - Common error response for all Azure Resource Manager APIs to return error details for failed operations.
// (This also follows the OData error response format.).
type ErrorResponse struct {
	// The error object.
	Error *ErrorDetail `json:"error,omitempty"`
}

// GrafanaClientBeginCreateOptions contains the optional parameters for the GrafanaClient.BeginCreate method.
type GrafanaClientBeginCreateOptions struct {
	// Resumes the LRO from the provided token.
	ResumeToken string
}

// GrafanaClientBeginDeleteOptions contains the optional parameters for the GrafanaClient.BeginDelete method.
type GrafanaClientBeginDeleteOptions struct {
	// Resumes the LRO from the provided token.
	ResumeToken string
}

// GrafanaClientGetOptions contains the optional parameters for the GrafanaClient.Get method.
type GrafanaClientGetOptions struct {
	// placeholder for future optional parameters
}

// GrafanaClientListByResourceGroupOptions contains the optional parameters for the GrafanaClient.ListByResourceGroup method.
type GrafanaClientListByResourceGroupOptions struct {
	// placeholder for future optional parameters
}

// GrafanaClientListOptions contains the optional parameters for the GrafanaClient.List method.
type GrafanaClientListOptions struct {
	// placeholder for future optional parameters
}

// GrafanaClientUpdateOptions contains the optional parameters for the GrafanaClient.Update method.
type GrafanaClientUpdateOptions struct {
	// placeholder for future optional parameters
}

// ManagedGrafana - The grafana resource type.
type ManagedGrafana struct {
	// The managed identity of the grafana resource.
	Identity *ManagedIdentity `json:"identity,omitempty"`

	// The geo-location where the grafana resource lives
	Location *string `json:"location,omitempty"`

	// Properties specific to the grafana resource.
	Properties *ManagedGrafanaProperties `json:"properties,omitempty"`

	// The Sku of the grafana resource.
	SKU *ResourceSKU `json:"sku,omitempty"`

	// The tags for grafana resource.
	Tags map[string]*string `json:"tags,omitempty"`

	// READ-ONLY; ARM id of the grafana resource
	ID *string `json:"id,omitempty" azure:"ro"`

	// READ-ONLY; Name of the grafana resource.
	Name *string `json:"name,omitempty" azure:"ro"`

	// READ-ONLY; The system meta data relating to this grafana resource.
	SystemData *SystemData `json:"systemData,omitempty" azure:"ro"`

	// READ-ONLY; The type of the grafana resource.
	Type *string `json:"type,omitempty" azure:"ro"`
}

type ManagedGrafanaListResponse struct {
	NextLink *string           `json:"nextLink,omitempty"`
	Value    []*ManagedGrafana `json:"value,omitempty"`
}

// ManagedGrafanaProperties - Properties specific to the grafana resource.
type ManagedGrafanaProperties struct {
	AutoGeneratedDomainNameLabelScope *AutoGeneratedDomainNameLabelScope `json:"autoGeneratedDomainNameLabelScope,omitempty"`

	// Provisioning state of the resource.
	ProvisioningState *ProvisioningState `json:"provisioningState,omitempty"`
	ZoneRedundancy    *ZoneRedundancy    `json:"zoneRedundancy,omitempty"`

	// READ-ONLY; The endpoint of the Grafana instance.
	Endpoint *string `json:"endpoint,omitempty" azure:"ro"`

	// READ-ONLY; The Grafana software version.
	GrafanaVersion *string `json:"grafanaVersion,omitempty" azure:"ro"`
}

// ManagedGrafanaUpdateParameters - The parameters for a PATCH request to a grafana resource.
type ManagedGrafanaUpdateParameters struct {
	// The managed identity of the grafana resource.
	Identity *ManagedIdentity `json:"identity,omitempty"`

	// The new tags of the grafana resource.
	Tags map[string]*string `json:"tags,omitempty"`
}

// ManagedIdentity - The managed identity of a resource.
type ManagedIdentity struct {
	// The type 'SystemAssigned, UserAssigned' includes both an implicitly created identity and a set of user assigned identities.
	// The type 'None' will remove any identities from the resource.
	Type *IdentityType `json:"type,omitempty"`

	// Dictionary of user assigned identities.
	UserAssignedIdentities map[string]*UserAssignedIdentity `json:"userAssignedIdentities,omitempty"`

	// READ-ONLY; The principal id of the system assigned identity.
	PrincipalID *string `json:"principalId,omitempty" azure:"ro"`

	// READ-ONLY; The tenant id of the system assigned identity.
	TenantID *string `json:"tenantId,omitempty" azure:"ro"`
}

// OperationDisplay - Localized display information for this particular operation.
type OperationDisplay struct {
	// READ-ONLY; Description of the operation, e.g., 'Read grafana'.
	Description *string `json:"description,omitempty" azure:"ro"`

	// READ-ONLY; Operation type, e.g., read, write, delete, etc.
	Operation *string `json:"operation,omitempty" azure:"ro"`

	// READ-ONLY; The localized friendly form of the resource provider name, i.e., Microsoft.Dashboard.
	Provider *string `json:"provider,omitempty" azure:"ro"`

	// READ-ONLY; The localized friendly name of the resource type related to this operation, e.g., 'grafana'.
	Resource *string `json:"resource,omitempty" azure:"ro"`
}

// OperationListResult - A list of REST API operations supported by Microsoft.Dashboard provider. It contains an URL link
// to get the next set of results.
type OperationListResult struct {
	// READ-ONLY; URL to get the next set of operation list results if there are any.
	NextLink *string `json:"nextLink,omitempty" azure:"ro"`

	// READ-ONLY; List of operations supported by the Microsoft.Dashboard provider.
	Value []*OperationResult `json:"value,omitempty" azure:"ro"`
}

// OperationResult - A Microsoft.Dashboard REST API operation.
type OperationResult struct {
	// Localized display information for this particular operation.
	Display *OperationDisplay `json:"display,omitempty"`

	// READ-ONLY; Indicates the action type. "Internal" refers to actions that are for internal only APIs.
	ActionType *ActionType `json:"actionType,omitempty" azure:"ro"`

	// READ-ONLY; Indicates whether the operation applies to data-plane. Set "true" for data-plane operations and "false" for
	// ARM/control-plane operations.
	IsDataAction *bool `json:"isDataAction,omitempty" azure:"ro"`

	// READ-ONLY; Operation name, i.e., {provider}/{resource}/{operation}.
	Name *string `json:"name,omitempty" azure:"ro"`

	// READ-ONLY; The intended executor of the operation.
	Origin *Origin `json:"origin,omitempty" azure:"ro"`
}

// OperationsClientListOptions contains the optional parameters for the OperationsClient.List method.
type OperationsClientListOptions struct {
	// placeholder for future optional parameters
}

type ResourceSKU struct {
	// REQUIRED
	Name *string `json:"name,omitempty"`
}

type SystemData struct {
	CreatedAt *time.Time `json:"createdAt,omitempty"`
	CreatedBy *string    `json:"createdBy,omitempty"`

	// The type of identity that created the resource.
	CreatedByType      *CreatedByType      `json:"createdByType,omitempty"`
	LastModifiedAt     *time.Time          `json:"lastModifiedAt,omitempty"`
	LastModifiedBy     *string             `json:"lastModifiedBy,omitempty"`
	LastModifiedByType *LastModifiedByType `json:"lastModifiedByType,omitempty"`
}

type UserAssignedIdentity struct {
	// READ-ONLY; The client id of user assigned identity.
	ClientID *string `json:"clientId,omitempty" azure:"ro"`

	// READ-ONLY; The principal id of user assigned identity.
	PrincipalID *string `json:"principalId,omitempty" azure:"ro"`
}
