//go:build go1.18
// +build go1.18

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.
// Code generated by Microsoft (R) AutoRest Code Generator.
// Changes may cause incorrect behavior and will be lost if the code is regenerated.

package armsecurityinsights_test

import (
	"context"
	"log"

	"github.com/Azure/azure-sdk-for-go/sdk/azcore/to"
	"github.com/Azure/azure-sdk-for-go/sdk/azidentity"
	"github.com/Azure/azure-sdk-for-go/sdk/resourcemanager/securityinsights/armsecurityinsights"
)

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/securityinsights/resource-manager/Microsoft.SecurityInsights/preview/2022-04-01-preview/examples/alertRules/GetAllAlertRules.json
func ExampleAlertRulesClient_NewListPager() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armsecurityinsights.NewAlertRulesClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	pager := client.NewListPager("<resource-group-name>",
		"<workspace-name>",
		nil)
	for pager.More() {
		nextResult, err := pager.NextPage(ctx)
		if err != nil {
			log.Fatalf("failed to advance page: %v", err)
			return
		}
		for _, v := range nextResult.Value {
			// TODO: use page item
			_ = v
		}
	}
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/securityinsights/resource-manager/Microsoft.SecurityInsights/preview/2022-04-01-preview/examples/alertRules/GetFusionAlertRule.json
func ExampleAlertRulesClient_Get() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armsecurityinsights.NewAlertRulesClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	res, err := client.Get(ctx,
		"<resource-group-name>",
		"<workspace-name>",
		"<rule-id>",
		nil)
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
	// TODO: use response item
	_ = res
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/securityinsights/resource-manager/Microsoft.SecurityInsights/preview/2022-04-01-preview/examples/alertRules/CreateFusionAlertRuleWithFusionScenarioExclusion.json
func ExampleAlertRulesClient_CreateOrUpdate() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armsecurityinsights.NewAlertRulesClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	res, err := client.CreateOrUpdate(ctx,
		"<resource-group-name>",
		"<workspace-name>",
		"<rule-id>",
		&armsecurityinsights.FusionAlertRule{
			Etag: to.Ptr("<etag>"),
			Kind: to.Ptr(armsecurityinsights.AlertRuleKindFusion),
			Properties: &armsecurityinsights.FusionAlertRuleProperties{
				AlertRuleTemplateName: to.Ptr("<alert-rule-template-name>"),
				Enabled:               to.Ptr(true),
				SourceSettings: []*armsecurityinsights.FusionSourceSettings{
					{
						Enabled:    to.Ptr(true),
						SourceName: to.Ptr("<source-name>"),
					},
					{
						Enabled:    to.Ptr(true),
						SourceName: to.Ptr("<source-name>"),
						SourceSubTypes: []*armsecurityinsights.FusionSourceSubTypeSetting{
							{
								Enabled: to.Ptr(true),
								SeverityFilters: &armsecurityinsights.FusionSubTypeSeverityFilter{
									Filters: []*armsecurityinsights.FusionSubTypeSeverityFiltersItem{
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityHigh),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityMedium),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityLow),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityInformational),
										}},
								},
								SourceSubTypeName: to.Ptr("<source-sub-type-name>"),
							},
							{
								Enabled: to.Ptr(true),
								SeverityFilters: &armsecurityinsights.FusionSubTypeSeverityFilter{
									Filters: []*armsecurityinsights.FusionSubTypeSeverityFiltersItem{
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityHigh),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityMedium),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityLow),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityInformational),
										}},
								},
								SourceSubTypeName: to.Ptr("<source-sub-type-name>"),
							},
							{
								Enabled: to.Ptr(true),
								SeverityFilters: &armsecurityinsights.FusionSubTypeSeverityFilter{
									Filters: []*armsecurityinsights.FusionSubTypeSeverityFiltersItem{
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityHigh),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityMedium),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityLow),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityInformational),
										}},
								},
								SourceSubTypeName: to.Ptr("<source-sub-type-name>"),
							},
							{
								Enabled: to.Ptr(true),
								SeverityFilters: &armsecurityinsights.FusionSubTypeSeverityFilter{
									Filters: []*armsecurityinsights.FusionSubTypeSeverityFiltersItem{
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityHigh),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityMedium),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityLow),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityInformational),
										}},
								},
								SourceSubTypeName: to.Ptr("<source-sub-type-name>"),
							},
							{
								Enabled: to.Ptr(true),
								SeverityFilters: &armsecurityinsights.FusionSubTypeSeverityFilter{
									Filters: []*armsecurityinsights.FusionSubTypeSeverityFiltersItem{
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityHigh),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityMedium),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityLow),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityInformational),
										}},
								},
								SourceSubTypeName: to.Ptr("<source-sub-type-name>"),
							},
							{
								Enabled: to.Ptr(true),
								SeverityFilters: &armsecurityinsights.FusionSubTypeSeverityFilter{
									Filters: []*armsecurityinsights.FusionSubTypeSeverityFiltersItem{
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityHigh),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityMedium),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityLow),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityInformational),
										}},
								},
								SourceSubTypeName: to.Ptr("<source-sub-type-name>"),
							},
							{
								Enabled: to.Ptr(true),
								SeverityFilters: &armsecurityinsights.FusionSubTypeSeverityFilter{
									Filters: []*armsecurityinsights.FusionSubTypeSeverityFiltersItem{
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityHigh),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityMedium),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityLow),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityInformational),
										}},
								},
								SourceSubTypeName: to.Ptr("<source-sub-type-name>"),
							},
							{
								Enabled: to.Ptr(true),
								SeverityFilters: &armsecurityinsights.FusionSubTypeSeverityFilter{
									Filters: []*armsecurityinsights.FusionSubTypeSeverityFiltersItem{
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityHigh),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityMedium),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityLow),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityInformational),
										}},
								},
								SourceSubTypeName: to.Ptr("<source-sub-type-name>"),
							},
							{
								Enabled: to.Ptr(true),
								SeverityFilters: &armsecurityinsights.FusionSubTypeSeverityFilter{
									Filters: []*armsecurityinsights.FusionSubTypeSeverityFiltersItem{
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityHigh),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityMedium),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityLow),
										},
										{
											Enabled:  to.Ptr(true),
											Severity: to.Ptr(armsecurityinsights.AlertSeverityInformational),
										}},
								},
								SourceSubTypeName: to.Ptr("<source-sub-type-name>"),
							}},
					},
					{
						Enabled:    to.Ptr(true),
						SourceName: to.Ptr("<source-name>"),
						SourceSubTypes: []*armsecurityinsights.FusionSourceSubTypeSetting{
							{
								Enabled:           to.Ptr(true),
								SeverityFilters:   &armsecurityinsights.FusionSubTypeSeverityFilter{},
								SourceSubTypeName: to.Ptr("<source-sub-type-name>"),
							}},
					}},
			},
		},
		nil)
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
	// TODO: use response item
	_ = res
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/securityinsights/resource-manager/Microsoft.SecurityInsights/preview/2022-04-01-preview/examples/alertRules/DeleteAlertRule.json
func ExampleAlertRulesClient_Delete() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armsecurityinsights.NewAlertRulesClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	_, err = client.Delete(ctx,
		"<resource-group-name>",
		"<workspace-name>",
		"<rule-id>",
		nil)
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
}
