//go:build go1.18
// +build go1.18

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.
// Code generated by Microsoft (R) AutoRest Code Generator.
// Changes may cause incorrect behavior and will be lost if the code is regenerated.

package armsecurityinsights_test

import (
	"context"
	"log"

	"time"

	"github.com/Azure/azure-sdk-for-go/sdk/azcore/to"
	"github.com/Azure/azure-sdk-for-go/sdk/azidentity"
	"github.com/Azure/azure-sdk-for-go/sdk/resourcemanager/securityinsights/armsecurityinsights"
)

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/securityinsights/resource-manager/Microsoft.SecurityInsights/preview/2022-04-01-preview/examples/metadata/GetAllMetadataOData.json
func ExampleMetadataClient_NewListPager() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armsecurityinsights.NewMetadataClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	pager := client.NewListPager("<resource-group-name>",
		"<workspace-name>",
		&armsecurityinsights.MetadataClientListOptions{Filter: nil,
			Orderby: nil,
			Top:     nil,
			Skip:    nil,
		})
	for pager.More() {
		nextResult, err := pager.NextPage(ctx)
		if err != nil {
			log.Fatalf("failed to advance page: %v", err)
			return
		}
		for _, v := range nextResult.Value {
			// TODO: use page item
			_ = v
		}
	}
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/securityinsights/resource-manager/Microsoft.SecurityInsights/preview/2022-04-01-preview/examples/metadata/GetMetadata.json
func ExampleMetadataClient_Get() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armsecurityinsights.NewMetadataClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	res, err := client.Get(ctx,
		"<resource-group-name>",
		"<workspace-name>",
		"<metadata-name>",
		nil)
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
	// TODO: use response item
	_ = res
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/securityinsights/resource-manager/Microsoft.SecurityInsights/preview/2022-04-01-preview/examples/metadata/DeleteMetadata.json
func ExampleMetadataClient_Delete() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armsecurityinsights.NewMetadataClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	_, err = client.Delete(ctx,
		"<resource-group-name>",
		"<workspace-name>",
		"<metadata-name>",
		nil)
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/securityinsights/resource-manager/Microsoft.SecurityInsights/preview/2022-04-01-preview/examples/metadata/PutMetadata.json
func ExampleMetadataClient_Create() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armsecurityinsights.NewMetadataClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	res, err := client.Create(ctx,
		"<resource-group-name>",
		"<workspace-name>",
		"<metadata-name>",
		armsecurityinsights.MetadataModel{
			Properties: &armsecurityinsights.MetadataProperties{
				Author: &armsecurityinsights.MetadataAuthor{
					Name:  to.Ptr("<name>"),
					Email: to.Ptr("<email>"),
				},
				Categories: &armsecurityinsights.MetadataCategories{
					Domains: []*string{
						to.Ptr("Application"),
						to.Ptr("Security – Insider Threat")},
					Verticals: []*string{
						to.Ptr("Healthcare")},
				},
				ContentID:            to.Ptr("<content-id>"),
				ContentSchemaVersion: to.Ptr("<content-schema-version>"),
				CustomVersion:        to.Ptr("<custom-version>"),
				Dependencies: &armsecurityinsights.MetadataDependencies{
					Criteria: []*armsecurityinsights.MetadataDependencies{
						{
							Criteria: []*armsecurityinsights.MetadataDependencies{
								{
									Name:      to.Ptr("<name>"),
									ContentID: to.Ptr("<content-id>"),
									Kind:      to.Ptr(armsecurityinsights.KindDataConnector),
								},
								{
									ContentID: to.Ptr("<content-id>"),
									Kind:      to.Ptr(armsecurityinsights.KindDataConnector),
								},
								{
									ContentID: to.Ptr("<content-id>"),
									Kind:      to.Ptr(armsecurityinsights.KindDataConnector),
									Version:   to.Ptr("<version>"),
								}},
							Operator: to.Ptr(armsecurityinsights.OperatorOR),
						},
						{
							ContentID: to.Ptr("<content-id>"),
							Kind:      to.Ptr(armsecurityinsights.KindPlaybook),
							Version:   to.Ptr("<version>"),
						},
						{
							ContentID: to.Ptr("<content-id>"),
							Kind:      to.Ptr(armsecurityinsights.KindParser),
						}},
					Operator: to.Ptr(armsecurityinsights.OperatorAND),
				},
				FirstPublishDate: to.Ptr(func() time.Time { t, _ := time.Parse("2006-01-02", "2021-05-18"); return t }()),
				Kind:             to.Ptr(armsecurityinsights.KindAnalyticsRule),
				LastPublishDate:  to.Ptr(func() time.Time { t, _ := time.Parse("2006-01-02", "2021-05-18"); return t }()),
				ParentID:         to.Ptr("<parent-id>"),
				PreviewImages: []*string{
					to.Ptr("firstImage.png"),
					to.Ptr("secondImage.jpeg")},
				PreviewImagesDark: []*string{
					to.Ptr("firstImageDark.png"),
					to.Ptr("secondImageDark.jpeg")},
				Providers: []*string{
					to.Ptr("Amazon"),
					to.Ptr("Microsoft")},
				Source: &armsecurityinsights.MetadataSource{
					Name:     to.Ptr("<name>"),
					Kind:     to.Ptr(armsecurityinsights.SourceKindSolution),
					SourceID: to.Ptr("<source-id>"),
				},
				Support: &armsecurityinsights.MetadataSupport{
					Name:  to.Ptr("<name>"),
					Email: to.Ptr("<email>"),
					Link:  to.Ptr("<link>"),
					Tier:  to.Ptr(armsecurityinsights.SupportTierPartner),
				},
				ThreatAnalysisTactics: []*string{
					to.Ptr("reconnaissance"),
					to.Ptr("commandandcontrol")},
				ThreatAnalysisTechniques: []*string{
					to.Ptr("T1548"),
					to.Ptr("T1548.001")},
				Version: to.Ptr("<version>"),
			},
		},
		nil)
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
	// TODO: use response item
	_ = res
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/securityinsights/resource-manager/Microsoft.SecurityInsights/preview/2022-04-01-preview/examples/metadata/PatchMetadata.json
func ExampleMetadataClient_Update() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armsecurityinsights.NewMetadataClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	res, err := client.Update(ctx,
		"<resource-group-name>",
		"<workspace-name>",
		"<metadata-name>",
		armsecurityinsights.MetadataPatch{
			Properties: &armsecurityinsights.MetadataPropertiesPatch{
				Author: &armsecurityinsights.MetadataAuthor{
					Name:  to.Ptr("<name>"),
					Email: to.Ptr("<email>"),
				},
			},
		},
		nil)
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
	// TODO: use response item
	_ = res
}
